@@ -393,4 +393,7 @@ def encode_request(headers, data, type=None, codec_register=DEFAULT_REGISTER):
             raise TypeError(
                 "Request data provided with no content type information")
         headers['content-type'], data = codec_register.encode(type, data)
+
+    if not headers['content-type']:
+        del headers['content-type']
     return headers, data
